@@ -164,7 +164,7 @@ class HierarchicalConstrainedClustering(AbstractConstrainedClustering):
         # Store `self.nb_clusters`.
         if nb_clusters < 2:
             raise ValueError("The `nb_clusters` '" + str(nb_clusters) + "' must be greater than or equal to 2.")
-        self.nb_clusters: int = nb_clusters
+        self.nb_clusters: int = min(nb_clusters, len(self.list_of_data_IDs))
 
         # Compute pairwise distances.
         matrix_of_pairwise_distances: csr_matrix = pairwise_distances(
