@@ -13,9 +13,8 @@
 # ==============================================================================
 
 from abc import ABC, abstractmethod  # To define an abstract class.
-from typing import Dict, List, Optional, Tuple, Union  # To type Python code (mypy).
+from typing import Dict, List, Optional, Tuple  # To type Python code (mypy).
 
-from numpy import ndarray  # To handle matrix and vectors.
 from scipy.sparse import csr_matrix  # To handle matrix and vectors.
 
 from cognitivefactory.interactive_clustering.constraints.abstract import (  # To manage constraints.
@@ -41,7 +40,7 @@ class AbstractConstraintsSampling(ABC):
         constraints_manager: AbstractConstraintsManager,
         nb_to_select: int,
         clustering_result: Optional[Dict[str, int]] = None,
-        vectors: Optional[Dict[str, Union[ndarray, csr_matrix]]] = None,
+        vectors: Optional[Dict[str, csr_matrix]] = None,
         **kargs,
     ) -> List[Tuple[str, str]]:
         """
@@ -52,7 +51,7 @@ class AbstractConstraintsSampling(ABC):
             constraints_manager (AbstractConstraintsManager): A constraints manager over data IDs.
             nb_to_select (int): The number of couple of data IDs to select.
             clustering_result (Optional[Dict[str,int]], optional): A dictionary that represents the predicted cluster for each data ID. The keys of the dictionary represents the data IDs. If `None`, no clustering result are used during the sampling. Defaults to `None`.
-            vectors (Optional[Dict[str,Union[ndarray,csr_matrix]]], optional): vectors (Dict[str,Union[ndarray,csr_matrix]]): The representation of data vectors. The keys of the dictionary represents the data IDs. This keys have to refer to the list of data IDs managed by the `constraints_manager`. The value of the dictionary represent the vector of each data. Vectors can be dense (`numpy.ndarray`) or sparse (`scipy.sparse.csr_matrix`). If `None`, no vectors are used during the sampling. Defaults to `None`
+            vectors (Optional[Dict[str, csr_matrix]], optional): vectors (Dict[str, csr_matrix]): The representation of data vectors. The keys of the dictionary represents the data IDs. This keys have to refer to the list of data IDs managed by the `constraints_manager`. The value of the dictionary represent the vector of each data. If `None`, no vectors are used during the sampling. Defaults to `None`
             **kargs (dict): Other parameters that can be used in the sampling.
 
         Raises:
