@@ -14,7 +14,10 @@
 
 import pytest
 
-from cognitivefactory.interactive_clustering.constraints.binary import BinaryConstraintsManager
+from cognitivefactory.interactive_clustering.constraints.binary import (
+    BinaryConstraintsManager,
+    load_constraints_manager_from_json,
+)
 
 
 # ==============================================================================
@@ -38,10 +41,10 @@ def test_BinaryConstraintsManager_init():
     assert constraints_manager_2.get_list_of_managed_data_IDs() == ["first", "second", "third"]
 
     # Initialize a binaray constraints manager with duplicates in `list_of_data_IDs`.
-    with pytest.raises(ValueError, match="`list_of_data_IDs`"):
-        BinaryConstraintsManager(
-            list_of_data_IDs=["first", "second", "same", "same"],
-        )
+    constraints_manager_3 = BinaryConstraintsManager(
+        list_of_data_IDs=["first", "second", "same", "same"],
+    )
+    assert constraints_manager_3.get_list_of_managed_data_IDs() == ["first", "second", "same"]
 
 
 # ==============================================================================
@@ -291,13 +294,10 @@ def test_BinaryConstraintsManager_add_constraint_with_not_already_linked_data_ID
         )
         is True
     )
-    assert (
-        constraints_manager.get_added_constraint(
-            data_ID1="first",
-            data_ID2="second",
-        )
-        == ("MUST_LINK", 1.0)
-    )
+    assert constraints_manager.get_added_constraint(
+        data_ID1="first",
+        data_ID2="second",
+    ) == ("MUST_LINK", 1.0)
 
     # Try to add `"CANNOT_LINK"` data ID between `"first"` and `"third"` data IDs.
     assert (
@@ -308,13 +308,10 @@ def test_BinaryConstraintsManager_add_constraint_with_not_already_linked_data_ID
         )
         is True
     )
-    assert (
-        constraints_manager.get_added_constraint(
-            data_ID1="first",
-            data_ID2="third",
-        )
-        == ("CANNOT_LINK", 1.0)
-    )
+    assert constraints_manager.get_added_constraint(
+        data_ID1="first",
+        data_ID2="third",
+    ) == ("CANNOT_LINK", 1.0)
 
     # Try to add `"MUST_LINK"` data ID between `"second"` and `"third"` data IDs.
     with pytest.raises(ValueError, match="`constraint_type`"):
@@ -333,13 +330,10 @@ def test_BinaryConstraintsManager_add_constraint_with_not_already_linked_data_ID
         )
         is True
     )
-    assert (
-        constraints_manager.get_added_constraint(
-            data_ID1="second",
-            data_ID2="third",
-        )
-        == ("CANNOT_LINK", 1.0)
-    )
+    assert constraints_manager.get_added_constraint(
+        data_ID1="second",
+        data_ID2="third",
+    ) == ("CANNOT_LINK", 1.0)
 
 
 # ==============================================================================
@@ -502,22 +496,16 @@ def test_BinaryConstraintsManager_get_added_constraint_with_correct_parameters()
     )
 
     # Try to get the constraint betwwen `"first"` and `"second"`.
-    assert (
-        constraints_manager.get_added_constraint(
-            data_ID1="first",
-            data_ID2="second",
-        )
-        == ("MUST_LINK", 1.0)
-    )
+    assert constraints_manager.get_added_constraint(
+        data_ID1="first",
+        data_ID2="second",
+    ) == ("MUST_LINK", 1.0)
 
     # Try to get the constraint betwwen `"first"` and `"third"`.
-    assert (
-        constraints_manager.get_added_constraint(
-            data_ID1="first",
-            data_ID2="third",
-        )
-        == ("CANNOT_LINK", 1.0)
-    )
+    assert constraints_manager.get_added_constraint(
+        data_ID1="first",
+        data_ID2="third",
+    ) == ("CANNOT_LINK", 1.0)
 
 
 # ==============================================================================
@@ -768,20 +756,14 @@ def test_BinaryConstraintsManager_check_symetry_after_constraint_addition():
     )
 
     # Run assertion on : ML(1,2) => ML(2,1).
-    assert (
-        constraints_manager.get_added_constraint(
-            data_ID1="first",
-            data_ID2="second",
-        )
-        == ("MUST_LINK", 1.0)
-    )
-    assert (
-        constraints_manager.get_added_constraint(
-            data_ID1="second",
-            data_ID2="first",
-        )
-        == ("MUST_LINK", 1.0)
-    )
+    assert constraints_manager.get_added_constraint(
+        data_ID1="first",
+        data_ID2="second",
+    ) == ("MUST_LINK", 1.0)
+    assert constraints_manager.get_added_constraint(
+        data_ID1="second",
+        data_ID2="first",
+    ) == ("MUST_LINK", 1.0)
     assert (
         constraints_manager.get_inferred_constraint(
             data_ID1="first",
@@ -798,20 +780,14 @@ def test_BinaryConstraintsManager_check_symetry_after_constraint_addition():
     )
 
     # Run assertion on : CL(1,3) => CL(3,1).
-    assert (
-        constraints_manager.get_added_constraint(
-            data_ID1="first",
-            data_ID2="third",
-        )
-        == ("CANNOT_LINK", 1.0)
-    )
-    assert (
-        constraints_manager.get_added_constraint(
-            data_ID1="third",
-            data_ID2="first",
-        )
-        == ("CANNOT_LINK", 1.0)
-    )
+    assert constraints_manager.get_added_constraint(
+        data_ID1="first",
+        data_ID2="third",
+    ) == ("CANNOT_LINK", 1.0)
+    assert constraints_manager.get_added_constraint(
+        data_ID1="third",
+        data_ID2="first",
+    ) == ("CANNOT_LINK", 1.0)
     assert (
         constraints_manager.get_inferred_constraint(
             data_ID1="first",
@@ -1259,24 +1235,18 @@ def test_BinaryConstraintsManager_get_list_of_involved_data_IDs_in_a_constraint_
     )
 
     # Conflict of adding `"MUST_LINK"` between "first" and "fourth".
-    assert (
-        constraints_manager.get_list_of_involved_data_IDs_in_a_constraint_conflict(
-            data_ID1="first",
-            data_ID2="fourth",
-            constraint_type="MUST_LINK",
-        )
-        == ["first", "second", "third", "fourth"]
-    )
+    assert constraints_manager.get_list_of_involved_data_IDs_in_a_constraint_conflict(
+        data_ID1="first",
+        data_ID2="fourth",
+        constraint_type="MUST_LINK",
+    ) == ["first", "second", "third", "fourth"]
 
     # Conflict of adding `"CANNOT_LINK"` between "first" and "fourth".
-    assert (
-        constraints_manager.get_list_of_involved_data_IDs_in_a_constraint_conflict(
-            data_ID1="first",
-            data_ID2="third",
-            constraint_type="CANNOT_LINK",
-        )
-        == ["first", "second", "third"]
-    )
+    assert constraints_manager.get_list_of_involved_data_IDs_in_a_constraint_conflict(
+        data_ID1="first",
+        data_ID2="third",
+        constraint_type="CANNOT_LINK",
+    ) == ["first", "second", "third"]
 
     # No conflict.
     assert (
@@ -1297,3 +1267,57 @@ def test_BinaryConstraintsManager_get_list_of_involved_data_IDs_in_a_constraint_
         )
         is None
     )
+
+
+# ==============================================================================
+# test_BinaryConstraintsManager_serialization
+# ==============================================================================
+def test_BinaryConstraintsManager_serialization():
+    """
+    Test that `to_json` and `load_constraints_manager_from_json` methods of the `constraints.binary.BinaryConstraintsManager` class work.
+    """
+
+    # Initialize a classic binary constraints manager.
+    constraints_manager_1 = BinaryConstraintsManager(
+        list_of_data_IDs=["first", "second", "third"],
+    )
+    constraints_manager_1.add_constraint(
+        data_ID1="first",
+        data_ID2="second",
+        constraint_type="MUST_LINK",
+    )
+    constraints_manager_1.add_constraint(
+        data_ID1="second",
+        data_ID2="third",
+        constraint_type="CANNOT_LINK",
+    )
+
+    # Serialize to JSON.
+    constraints_manager_1.to_json(
+        filepath="./tests/temp/test_BinaryConstraintsManager_to_json__constraints_manager_1.json",
+    )
+
+    # Deserialize from JSON
+    constraints_manager_2 = load_constraints_manager_from_json(
+        filepath="./tests/temp/test_BinaryConstraintsManager_to_json__constraints_manager_1.json",
+    )
+
+    # Assert type.
+    assert isinstance(constraints_manager_2, BinaryConstraintsManager)
+
+    # Assert data IDs storage is the same.
+    assert constraints_manager_1.get_list_of_managed_data_IDs() == constraints_manager_2.get_list_of_managed_data_IDs()
+
+    # Assert constraints storage.
+    assert constraints_manager_1.get_added_constraint(
+        data_ID1="first", data_ID2="second"
+    ) == constraints_manager_2.get_added_constraint(data_ID1="first", data_ID2="second")
+    assert constraints_manager_1.get_added_constraint(
+        data_ID1="second", data_ID2="third"
+    ) == constraints_manager_2.get_added_constraint(data_ID1="second", data_ID2="third")
+
+    # Assert constraints transitivity.
+
+    assert constraints_manager_1.get_inferred_constraint(
+        data_ID1="first", data_ID2="third"
+    ) == constraints_manager_2.get_inferred_constraint(data_ID1="first", data_ID2="third")
