@@ -103,7 +103,7 @@ def test_vectorize_for_installed_spacy_language_model():
             "2": "hello where do you live",
         },
         vectorizer_type="spacy",
-        spacy_language_model="en_core_web_sm",
+        spacy_language_model="en_core_web_md",
     )
 
     # Assertions
